@@ -16,7 +16,7 @@ our @EXPORT = qw(
 	pause_add_uri
 	);
 
-$VERSION = '2.07';
+$VERSION = '2.08';
 
 =encoding utf8
 
@@ -68,7 +68,8 @@ sub web_upload {
 
 sub make_agent {
 	my( $self ) = @_;
-	my $agent = Mojo::UserAgent->new( name => 'release' );
+	my $agent = Mojo::UserAgent->new;
+	$agent->transactor->name( 'release' );
 	$agent->http_proxy( $self->config->http_proxy ) if $self->config->http_proxy;
 	$agent->https_proxy( $self->config->https_proxy ) if $self->config->https_proxy;
 	require CACertOrg::CA;
@@ -121,7 +122,7 @@ brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2007-2013, brian d foy, All Rights Reserved.
+Copyright (c) 2007-2014, brian d foy, All Rights Reserved.
 
 You may redistribute this under the same terms as Perl itself.
 
